# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_messages.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='data_messages.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x64\x61ta_messages.proto\"\x80\x01\n\x06PbMeta\x12\x12\n\x05title\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03URL\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x0cuser_defined\x18\x04 \x03(\tB\x08\n\x06_titleB\x0e\n\x0c_descriptionB\x06\n\x04_URL\"\xaa\x01\n\nPbTimeZone\x12\x12\n\x05hours\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07minutes\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x0cstring_basic\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1c\n\x0fstring_extended\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_hoursB\n\n\x08_minutesB\x0f\n\r_string_basicB\x12\n\x10_string_extended\"\xc3\t\n\nPbWorkflow\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06status\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04host\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x11\n\x04port\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x12\n\x05owner\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\r\n\x05tasks\x18\x08 \x03(\t\x12\x10\n\x08\x66\x61milies\x18\t \x03(\t\x12\x1c\n\x05\x65\x64ges\x18\n \x01(\x0b\x32\x08.PbEdgesH\x07\x88\x01\x01\x12\x18\n\x0b\x61pi_version\x18\x0b \x01(\x05H\x08\x88\x01\x01\x12\x19\n\x0c\x63ylc_version\x18\x0c \x01(\tH\t\x88\x01\x01\x12\x19\n\x0clast_updated\x18\r \x01(\x01H\n\x88\x01\x01\x12\x1a\n\x04meta\x18\x0e \x01(\x0b\x32\x07.PbMetaH\x0b\x88\x01\x01\x12(\n\x1bnewest_runahead_cycle_point\x18\x0f \x01(\tH\x0c\x88\x01\x01\x12\x1f\n\x12newest_cycle_point\x18\x10 \x01(\tH\r\x88\x01\x01\x12\x1f\n\x12oldest_cycle_point\x18\x11 \x01(\tH\x0e\x88\x01\x01\x12\x15\n\x08reloaded\x18\x12 \x01(\x08H\x0f\x88\x01\x01\x12\x15\n\x08run_mode\x18\x13 \x01(\tH\x10\x88\x01\x01\x12\x19\n\x0c\x63ycling_mode\x18\x14 \x01(\tH\x11\x88\x01\x01\x12\x32\n\x0cstate_totals\x18\x15 \x03(\x0b\x32\x1c.PbWorkflow.StateTotalsEntry\x12\x1d\n\x10workflow_log_dir\x18\x16 \x01(\tH\x12\x88\x01\x01\x12(\n\x0etime_zone_info\x18\x17 \x01(\x0b\x32\x0b.PbTimeZoneH\x13\x88\x01\x01\x12\x17\n\ntree_depth\x18\x18 \x01(\x05H\x14\x88\x01\x01\x12\x15\n\rjob_log_names\x18\x19 \x03(\t\x12\x15\n\rns_defn_order\x18\x1a \x03(\t\x12\x0e\n\x06states\x18\x1b \x03(\t\x12\x14\n\x0ctask_proxies\x18\x1c \x03(\t\x12\x16\n\x0e\x66\x61mily_proxies\x18\x1d \x03(\t\x12\x17\n\nstatus_msg\x18\x1e \x01(\tH\x15\x88\x01\x01\x12\x1a\n\ris_held_total\x18\x1f \x01(\x05H\x16\x88\x01\x01\x12\x0c\n\x04jobs\x18  \x03(\t\x1a\x32\n\x10StateTotalsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x42\x08\n\x06_stampB\x05\n\x03_idB\x07\n\x05_nameB\t\n\x07_statusB\x07\n\x05_hostB\x07\n\x05_portB\x08\n\x06_ownerB\x08\n\x06_edgesB\x0e\n\x0c_api_versionB\x0f\n\r_cylc_versionB\x0f\n\r_last_updatedB\x07\n\x05_metaB\x1e\n\x1c_newest_runahead_cycle_pointB\x15\n\x13_newest_cycle_pointB\x15\n\x13_oldest_cycle_pointB\x0b\n\t_reloadedB\x0b\n\t_run_modeB\x0f\n\r_cycling_modeB\x13\n\x11_workflow_log_dirB\x11\n\x0f_time_zone_infoB\r\n\x0b_tree_depthB\r\n\x0b_status_msgB\x10\n\x0e_is_held_total\"\xf1\x08\n\x05PbJob\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nsubmit_num\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x12\n\x05state\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\ntask_proxy\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1b\n\x0esubmitted_time\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0cstarted_time\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1a\n\rfinished_time\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1d\n\x10\x62\x61tch_sys_job_id\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0e\x62\x61tch_sys_name\x18\n \x01(\tH\t\x88\x01\x01\x12\x17\n\nenv_script\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x17\n\nerr_script\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x18\n\x0b\x65xit_script\x18\r \x01(\tH\x0c\x88\x01\x01\x12!\n\x14\x65xecution_time_limit\x18\x0e \x01(\x02H\r\x88\x01\x01\x12\x11\n\x04host\x18\x0f \x01(\tH\x0e\x88\x01\x01\x12\x18\n\x0binit_script\x18\x10 \x01(\tH\x0f\x88\x01\x01\x12\x18\n\x0bjob_log_dir\x18\x11 \x01(\tH\x10\x88\x01\x01\x12\x12\n\x05owner\x18\x12 \x01(\tH\x11\x88\x01\x01\x12\x18\n\x0bpost_script\x18\x13 \x01(\tH\x12\x88\x01\x01\x12\x17\n\npre_script\x18\x14 \x01(\tH\x13\x88\x01\x01\x12\x13\n\x06script\x18\x15 \x01(\tH\x14\x88\x01\x01\x12\x12\n\x05shell\x18\x16 \x01(\tH\x15\x88\x01\x01\x12\x19\n\x0cwork_sub_dir\x18\x17 \x01(\tH\x16\x88\x01\x01\x12\x16\n\x0e\x62\x61tch_sys_conf\x18\x18 \x03(\t\x12\x13\n\x0b\x65nvironment\x18\x19 \x03(\t\x12\x12\n\ndirectives\x18\x1a \x03(\t\x12\x16\n\x0eparam_env_tmpl\x18\x1b \x03(\t\x12\x11\n\tparam_var\x18\x1c \x03(\t\x12\x12\n\nextra_logs\x18\x1d \x03(\t\x12\x11\n\x04name\x18\x1e \x01(\tH\x17\x88\x01\x01\x12\x18\n\x0b\x63ycle_point\x18\x1f \x01(\tH\x18\x88\x01\x01\x12\x10\n\x08messages\x18  \x03(\tB\x08\n\x06_stampB\x05\n\x03_idB\r\n\x0b_submit_numB\x08\n\x06_stateB\r\n\x0b_task_proxyB\x11\n\x0f_submitted_timeB\x0f\n\r_started_timeB\x10\n\x0e_finished_timeB\x13\n\x11_batch_sys_job_idB\x11\n\x0f_batch_sys_nameB\r\n\x0b_env_scriptB\r\n\x0b_err_scriptB\x0e\n\x0c_exit_scriptB\x17\n\x15_execution_time_limitB\x07\n\x05_hostB\x0e\n\x0c_init_scriptB\x0e\n\x0c_job_log_dirB\x08\n\x06_ownerB\x0e\n\x0c_post_scriptB\r\n\x0b_pre_scriptB\t\n\x07_scriptB\x08\n\x06_shellB\x0f\n\r_work_sub_dirB\x07\n\x05_nameB\x0e\n\x0c_cycle_point\"\xf7\x01\n\x06PbTask\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\x04meta\x18\x04 \x01(\x0b\x32\x07.PbMetaH\x03\x88\x01\x01\x12\x1e\n\x11mean_elapsed_time\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x12\n\x05\x64\x65pth\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x0f\n\x07proxies\x18\x07 \x03(\t\x12\x11\n\tnamespace\x18\x08 \x03(\tB\x08\n\x06_stampB\x05\n\x03_idB\x07\n\x05_nameB\x07\n\x05_metaB\x14\n\x12_mean_elapsed_timeB\x08\n\x06_depth\"\xd8\x01\n\nPbPollTask\x12\x18\n\x0blocal_proxy\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08workflow\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x0cremote_proxy\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\treq_state\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x19\n\x0cgraph_string\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x0e\n\x0c_local_proxyB\x0b\n\t_workflowB\x0f\n\r_remote_proxyB\x0c\n\n_req_stateB\x0f\n\r_graph_string\"\xcb\x01\n\x0bPbCondition\x12\x17\n\ntask_proxy\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nexpr_alias\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\treq_state\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tsatisfied\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x14\n\x07message\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\r\n\x0b_task_proxyB\r\n\x0b_expr_aliasB\x0c\n\n_req_stateB\x0c\n\n_satisfiedB\n\n\x08_message\"\x96\x01\n\x0ePbPrerequisite\x12\x17\n\nexpression\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\nconditions\x18\x02 \x03(\x0b\x32\x0c.PbCondition\x12\x14\n\x0c\x63ycle_points\x18\x03 \x03(\t\x12\x16\n\tsatisfied\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\r\n\x0b_expressionB\x0c\n\n_satisfied\"\xcc\x04\n\x0bPbTaskProxy\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04task\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05state\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x63ycle_point\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x14\n\x07spawned\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x12\n\x05\x64\x65pth\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x18\n\x0bjob_submits\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1b\n\x0elatest_message\x18\t \x01(\tH\x08\x88\x01\x01\x12\x0f\n\x07outputs\x18\n \x03(\t\x12\x12\n\nbroadcasts\x18\x0b \x03(\t\x12\x11\n\tnamespace\x18\x0c \x03(\t\x12&\n\rprerequisites\x18\r \x03(\x0b\x32\x0f.PbPrerequisite\x12\x0c\n\x04jobs\x18\x0e \x03(\t\x12\x0f\n\x07parents\x18\x0f \x03(\t\x12\x19\n\x0c\x66irst_parent\x18\x10 \x01(\tH\t\x88\x01\x01\x12\x11\n\x04name\x18\x11 \x01(\tH\n\x88\x01\x01\x12\x14\n\x07is_held\x18\x12 \x01(\x08H\x0b\x88\x01\x01\x12\r\n\x05\x65\x64ges\x18\x13 \x03(\t\x12\x11\n\tancestors\x18\x14 \x03(\tB\x08\n\x06_stampB\x05\n\x03_idB\x07\n\x05_taskB\x08\n\x06_stateB\x0e\n\x0c_cycle_pointB\n\n\x08_spawnedB\x08\n\x06_depthB\x0e\n\x0c_job_submitsB\x11\n\x0f_latest_messageB\x0f\n\r_first_parentB\x07\n\x05_nameB\n\n\x08_is_held\"\xee\x01\n\x08PbFamily\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\x04meta\x18\x04 \x01(\x0b\x32\x07.PbMetaH\x03\x88\x01\x01\x12\x12\n\x05\x64\x65pth\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x0f\n\x07proxies\x18\x06 \x03(\t\x12\x0f\n\x07parents\x18\x07 \x03(\t\x12\x13\n\x0b\x63hild_tasks\x18\x08 \x03(\t\x12\x16\n\x0e\x63hild_families\x18\t \x03(\tB\x08\n\x06_stampB\x05\n\x03_idB\x07\n\x05_nameB\x07\n\x05_metaB\x08\n\x06_depth\"\x86\x03\n\rPbFamilyProxy\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x63ycle_point\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06\x66\x61mily\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x12\n\x05state\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x12\n\x05\x64\x65pth\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0c\x66irst_parent\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x0f\n\x07parents\x18\t \x03(\t\x12\x13\n\x0b\x63hild_tasks\x18\n \x03(\t\x12\x16\n\x0e\x63hild_families\x18\x0b \x03(\t\x12\x14\n\x07is_held\x18\x0c \x01(\x08H\x08\x88\x01\x01\x12\x11\n\tancestors\x18\r \x03(\tB\x08\n\x06_stampB\x05\n\x03_idB\x0e\n\x0c_cycle_pointB\x07\n\x05_nameB\t\n\x07_familyB\x08\n\x06_stateB\x08\n\x06_depthB\x0f\n\r_first_parentB\n\n\x08_is_held\"\xbc\x01\n\x06PbEdge\x12\x12\n\x05stamp\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06source\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06target\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x14\n\x07suicide\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x11\n\x04\x63ond\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\x08\n\x06_stampB\x05\n\x03_idB\t\n\x07_sourceB\t\n\x07_targetB\n\n\x08_suicideB\x07\n\x05_cond\"{\n\x07PbEdges\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05\x65\x64ges\x18\x02 \x03(\t\x12+\n\x16workflow_polling_tasks\x18\x03 \x03(\x0b\x32\x0b.PbPollTask\x12\x0e\n\x06leaves\x18\x04 \x03(\t\x12\x0c\n\x04\x66\x65\x65t\x18\x05 \x03(\tB\x05\n\x03_id\"\xf2\x01\n\x10PbEntireWorkflow\x12\"\n\x08workflow\x18\x01 \x01(\x0b\x32\x0b.PbWorkflowH\x00\x88\x01\x01\x12\x16\n\x05tasks\x18\x02 \x03(\x0b\x32\x07.PbTask\x12\"\n\x0ctask_proxies\x18\x03 \x03(\x0b\x32\x0c.PbTaskProxy\x12\x14\n\x04jobs\x18\x04 \x03(\x0b\x32\x06.PbJob\x12\x1b\n\x08\x66\x61milies\x18\x05 \x03(\x0b\x32\t.PbFamily\x12&\n\x0e\x66\x61mily_proxies\x18\x06 \x03(\x0b\x32\x0e.PbFamilyProxy\x12\x16\n\x05\x65\x64ges\x18\x07 \x03(\x0b\x32\x07.PbEdgeB\x0b\n\t_workflow\"\xaf\x01\n\x07\x45\x44\x65ltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x16\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32\x07.PbEdge\x12\x18\n\x07updated\x18\x04 \x03(\x0b\x32\x07.PbEdge\x12\x0e\n\x06pruned\x18\x05 \x03(\t\x12\x15\n\x08reloaded\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_timeB\x0b\n\t_checksumB\x0b\n\t_reloaded\"\xb3\x01\n\x07\x46\x44\x65ltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x18\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32\t.PbFamily\x12\x1a\n\x07updated\x18\x04 \x03(\x0b\x32\t.PbFamily\x12\x0e\n\x06pruned\x18\x05 \x03(\t\x12\x15\n\x08reloaded\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_timeB\x0b\n\t_checksumB\x0b\n\t_reloaded\"\xbe\x01\n\x08\x46PDeltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1d\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32\x0e.PbFamilyProxy\x12\x1f\n\x07updated\x18\x04 \x03(\x0b\x32\x0e.PbFamilyProxy\x12\x0e\n\x06pruned\x18\x05 \x03(\t\x12\x15\n\x08reloaded\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_timeB\x0b\n\t_checksumB\x0b\n\t_reloaded\"\xad\x01\n\x07JDeltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32\x06.PbJob\x12\x17\n\x07updated\x18\x04 \x03(\x0b\x32\x06.PbJob\x12\x0e\n\x06pruned\x18\x05 \x03(\t\x12\x15\n\x08reloaded\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_timeB\x0b\n\t_checksumB\x0b\n\t_reloaded\"\xaf\x01\n\x07TDeltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x16\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32\x07.PbTask\x12\x18\n\x07updated\x18\x04 \x03(\x0b\x32\x07.PbTask\x12\x0e\n\x06pruned\x18\x05 \x03(\t\x12\x15\n\x08reloaded\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_timeB\x0b\n\t_checksumB\x0b\n\t_reloaded\"\xba\x01\n\x08TPDeltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1b\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32\x0c.PbTaskProxy\x12\x1d\n\x07updated\x18\x04 \x03(\x0b\x32\x0c.PbTaskProxy\x12\x0e\n\x06pruned\x18\x05 \x03(\t\x12\x15\n\x08reloaded\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_timeB\x0b\n\t_checksumB\x0b\n\t_reloaded\"\xa3\x01\n\x07WDeltas\x12\x11\n\x04time\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1f\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x0b\x32\x0b.PbWorkflowH\x01\x88\x01\x01\x12!\n\x07updated\x18\x03 \x01(\x0b\x32\x0b.PbWorkflowH\x02\x88\x01\x01\x12\x15\n\x08reloaded\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x07\n\x05_timeB\x08\n\x06_addedB\n\n\x08_updatedB\x0b\n\t_reloaded\"\xd1\x01\n\tAllDeltas\x12\x1a\n\x08\x66\x61milies\x18\x01 \x01(\x0b\x32\x08.FDeltas\x12!\n\x0e\x66\x61mily_proxies\x18\x02 \x01(\x0b\x32\t.FPDeltas\x12\x16\n\x04jobs\x18\x03 \x01(\x0b\x32\x08.JDeltas\x12\x17\n\x05tasks\x18\x04 \x01(\x0b\x32\x08.TDeltas\x12\x1f\n\x0ctask_proxies\x18\x05 \x01(\x0b\x32\t.TPDeltas\x12\x17\n\x05\x65\x64ges\x18\x06 \x01(\x0b\x32\x08.EDeltas\x12\x1a\n\x08workflow\x18\x07 \x01(\x0b\x32\x08.WDeltasb\x06proto3'
)




_PBMETA = _descriptor.Descriptor(
  name='PbMeta',
  full_name='PbMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='PbMeta.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='PbMeta.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='URL', full_name='PbMeta.URL', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_defined', full_name='PbMeta.user_defined', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_title', full_name='PbMeta._title',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_description', full_name='PbMeta._description',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_URL', full_name='PbMeta._URL',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=24,
  serialized_end=152,
)


_PBTIMEZONE = _descriptor.Descriptor(
  name='PbTimeZone',
  full_name='PbTimeZone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hours', full_name='PbTimeZone.hours', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes', full_name='PbTimeZone.minutes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_basic', full_name='PbTimeZone.string_basic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_extended', full_name='PbTimeZone.string_extended', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_hours', full_name='PbTimeZone._hours',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_minutes', full_name='PbTimeZone._minutes',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_string_basic', full_name='PbTimeZone._string_basic',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_string_extended', full_name='PbTimeZone._string_extended',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=155,
  serialized_end=325,
)


_PBWORKFLOW_STATETOTALSENTRY = _descriptor.Descriptor(
  name='StateTotalsEntry',
  full_name='PbWorkflow.StateTotalsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PbWorkflow.StateTotalsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PbWorkflow.StateTotalsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1204,
)

_PBWORKFLOW = _descriptor.Descriptor(
  name='PbWorkflow',
  full_name='PbWorkflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbWorkflow.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbWorkflow.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PbWorkflow.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='PbWorkflow.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='PbWorkflow.host', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='PbWorkflow.port', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='PbWorkflow.owner', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='PbWorkflow.tasks', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='families', full_name='PbWorkflow.families', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='PbWorkflow.edges', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_version', full_name='PbWorkflow.api_version', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cylc_version', full_name='PbWorkflow.cylc_version', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='PbWorkflow.last_updated', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='PbWorkflow.meta', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newest_runahead_cycle_point', full_name='PbWorkflow.newest_runahead_cycle_point', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newest_cycle_point', full_name='PbWorkflow.newest_cycle_point', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oldest_cycle_point', full_name='PbWorkflow.oldest_cycle_point', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='PbWorkflow.reloaded', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_mode', full_name='PbWorkflow.run_mode', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycling_mode', full_name='PbWorkflow.cycling_mode', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_totals', full_name='PbWorkflow.state_totals', index=20,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_log_dir', full_name='PbWorkflow.workflow_log_dir', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone_info', full_name='PbWorkflow.time_zone_info', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tree_depth', full_name='PbWorkflow.tree_depth', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_log_names', full_name='PbWorkflow.job_log_names', index=24,
      number=25, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ns_defn_order', full_name='PbWorkflow.ns_defn_order', index=25,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='PbWorkflow.states', index=26,
      number=27, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_proxies', full_name='PbWorkflow.task_proxies', index=27,
      number=28, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family_proxies', full_name='PbWorkflow.family_proxies', index=28,
      number=29, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_msg', full_name='PbWorkflow.status_msg', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_held_total', full_name='PbWorkflow.is_held_total', index=30,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobs', full_name='PbWorkflow.jobs', index=31,
      number=32, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PBWORKFLOW_STATETOTALSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbWorkflow._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbWorkflow._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_name', full_name='PbWorkflow._name',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status', full_name='PbWorkflow._status',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_host', full_name='PbWorkflow._host',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_port', full_name='PbWorkflow._port',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_owner', full_name='PbWorkflow._owner',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_edges', full_name='PbWorkflow._edges',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_api_version', full_name='PbWorkflow._api_version',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cylc_version', full_name='PbWorkflow._cylc_version',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_last_updated', full_name='PbWorkflow._last_updated',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_meta', full_name='PbWorkflow._meta',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_newest_runahead_cycle_point', full_name='PbWorkflow._newest_runahead_cycle_point',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_newest_cycle_point', full_name='PbWorkflow._newest_cycle_point',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_oldest_cycle_point', full_name='PbWorkflow._oldest_cycle_point',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='PbWorkflow._reloaded',
      index=15, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_run_mode', full_name='PbWorkflow._run_mode',
      index=16, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cycling_mode', full_name='PbWorkflow._cycling_mode',
      index=17, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_workflow_log_dir', full_name='PbWorkflow._workflow_log_dir',
      index=18, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_time_zone_info', full_name='PbWorkflow._time_zone_info',
      index=19, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tree_depth', full_name='PbWorkflow._tree_depth',
      index=20, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_msg', full_name='PbWorkflow._status_msg',
      index=21, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_is_held_total', full_name='PbWorkflow._is_held_total',
      index=22, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=328,
  serialized_end=1547,
)


_PBJOB = _descriptor.Descriptor(
  name='PbJob',
  full_name='PbJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbJob.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbJob.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submit_num', full_name='PbJob.submit_num', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='PbJob.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_proxy', full_name='PbJob.task_proxy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_time', full_name='PbJob.submitted_time', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_time', full_name='PbJob.started_time', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished_time', full_name='PbJob.finished_time', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_sys_job_id', full_name='PbJob.batch_sys_job_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_sys_name', full_name='PbJob.batch_sys_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_script', full_name='PbJob.env_script', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='err_script', full_name='PbJob.err_script', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_script', full_name='PbJob.exit_script', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_time_limit', full_name='PbJob.execution_time_limit', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='PbJob.host', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_script', full_name='PbJob.init_script', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_log_dir', full_name='PbJob.job_log_dir', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='PbJob.owner', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_script', full_name='PbJob.post_script', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre_script', full_name='PbJob.pre_script', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script', full_name='PbJob.script', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shell', full_name='PbJob.shell', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='work_sub_dir', full_name='PbJob.work_sub_dir', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_sys_conf', full_name='PbJob.batch_sys_conf', index=23,
      number=24, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='PbJob.environment', index=24,
      number=25, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directives', full_name='PbJob.directives', index=25,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='param_env_tmpl', full_name='PbJob.param_env_tmpl', index=26,
      number=27, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='param_var', full_name='PbJob.param_var', index=27,
      number=28, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_logs', full_name='PbJob.extra_logs', index=28,
      number=29, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PbJob.name', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle_point', full_name='PbJob.cycle_point', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='PbJob.messages', index=31,
      number=32, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbJob._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbJob._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_submit_num', full_name='PbJob._submit_num',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_state', full_name='PbJob._state',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_task_proxy', full_name='PbJob._task_proxy',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_submitted_time', full_name='PbJob._submitted_time',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_started_time', full_name='PbJob._started_time',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_finished_time', full_name='PbJob._finished_time',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_batch_sys_job_id', full_name='PbJob._batch_sys_job_id',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_batch_sys_name', full_name='PbJob._batch_sys_name',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_env_script', full_name='PbJob._env_script',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_err_script', full_name='PbJob._err_script',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_exit_script', full_name='PbJob._exit_script',
      index=12, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_execution_time_limit', full_name='PbJob._execution_time_limit',
      index=13, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_host', full_name='PbJob._host',
      index=14, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_init_script', full_name='PbJob._init_script',
      index=15, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_job_log_dir', full_name='PbJob._job_log_dir',
      index=16, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_owner', full_name='PbJob._owner',
      index=17, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_post_script', full_name='PbJob._post_script',
      index=18, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pre_script', full_name='PbJob._pre_script',
      index=19, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_script', full_name='PbJob._script',
      index=20, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_shell', full_name='PbJob._shell',
      index=21, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_work_sub_dir', full_name='PbJob._work_sub_dir',
      index=22, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_name', full_name='PbJob._name',
      index=23, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cycle_point', full_name='PbJob._cycle_point',
      index=24, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1550,
  serialized_end=2687,
)


_PBTASK = _descriptor.Descriptor(
  name='PbTask',
  full_name='PbTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbTask.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbTask.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PbTask.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='PbTask.meta', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_elapsed_time', full_name='PbTask.mean_elapsed_time', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='PbTask.depth', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxies', full_name='PbTask.proxies', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='PbTask.namespace', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbTask._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbTask._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_name', full_name='PbTask._name',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_meta', full_name='PbTask._meta',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_mean_elapsed_time', full_name='PbTask._mean_elapsed_time',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_depth', full_name='PbTask._depth',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2690,
  serialized_end=2937,
)


_PBPOLLTASK = _descriptor.Descriptor(
  name='PbPollTask',
  full_name='PbPollTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_proxy', full_name='PbPollTask.local_proxy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='PbPollTask.workflow', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_proxy', full_name='PbPollTask.remote_proxy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_state', full_name='PbPollTask.req_state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='graph_string', full_name='PbPollTask.graph_string', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_local_proxy', full_name='PbPollTask._local_proxy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_workflow', full_name='PbPollTask._workflow',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_remote_proxy', full_name='PbPollTask._remote_proxy',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_req_state', full_name='PbPollTask._req_state',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_graph_string', full_name='PbPollTask._graph_string',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2940,
  serialized_end=3156,
)


_PBCONDITION = _descriptor.Descriptor(
  name='PbCondition',
  full_name='PbCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_proxy', full_name='PbCondition.task_proxy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expr_alias', full_name='PbCondition.expr_alias', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_state', full_name='PbCondition.req_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satisfied', full_name='PbCondition.satisfied', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='PbCondition.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_task_proxy', full_name='PbCondition._task_proxy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_expr_alias', full_name='PbCondition._expr_alias',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_req_state', full_name='PbCondition._req_state',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_satisfied', full_name='PbCondition._satisfied',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_message', full_name='PbCondition._message',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3159,
  serialized_end=3362,
)


_PBPREREQUISITE = _descriptor.Descriptor(
  name='PbPrerequisite',
  full_name='PbPrerequisite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expression', full_name='PbPrerequisite.expression', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='PbPrerequisite.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle_points', full_name='PbPrerequisite.cycle_points', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satisfied', full_name='PbPrerequisite.satisfied', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_expression', full_name='PbPrerequisite._expression',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_satisfied', full_name='PbPrerequisite._satisfied',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3365,
  serialized_end=3515,
)


_PBTASKPROXY = _descriptor.Descriptor(
  name='PbTaskProxy',
  full_name='PbTaskProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbTaskProxy.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbTaskProxy.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task', full_name='PbTaskProxy.task', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='PbTaskProxy.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle_point', full_name='PbTaskProxy.cycle_point', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spawned', full_name='PbTaskProxy.spawned', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='PbTaskProxy.depth', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_submits', full_name='PbTaskProxy.job_submits', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_message', full_name='PbTaskProxy.latest_message', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='PbTaskProxy.outputs', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='PbTaskProxy.broadcasts', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='PbTaskProxy.namespace', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prerequisites', full_name='PbTaskProxy.prerequisites', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobs', full_name='PbTaskProxy.jobs', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parents', full_name='PbTaskProxy.parents', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_parent', full_name='PbTaskProxy.first_parent', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PbTaskProxy.name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_held', full_name='PbTaskProxy.is_held', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='PbTaskProxy.edges', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ancestors', full_name='PbTaskProxy.ancestors', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbTaskProxy._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbTaskProxy._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_task', full_name='PbTaskProxy._task',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_state', full_name='PbTaskProxy._state',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cycle_point', full_name='PbTaskProxy._cycle_point',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_spawned', full_name='PbTaskProxy._spawned',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_depth', full_name='PbTaskProxy._depth',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_job_submits', full_name='PbTaskProxy._job_submits',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_latest_message', full_name='PbTaskProxy._latest_message',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_first_parent', full_name='PbTaskProxy._first_parent',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_name', full_name='PbTaskProxy._name',
      index=10, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_is_held', full_name='PbTaskProxy._is_held',
      index=11, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3518,
  serialized_end=4106,
)


_PBFAMILY = _descriptor.Descriptor(
  name='PbFamily',
  full_name='PbFamily',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbFamily.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbFamily.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PbFamily.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='PbFamily.meta', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='PbFamily.depth', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxies', full_name='PbFamily.proxies', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parents', full_name='PbFamily.parents', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_tasks', full_name='PbFamily.child_tasks', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_families', full_name='PbFamily.child_families', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbFamily._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbFamily._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_name', full_name='PbFamily._name',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_meta', full_name='PbFamily._meta',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_depth', full_name='PbFamily._depth',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4109,
  serialized_end=4347,
)


_PBFAMILYPROXY = _descriptor.Descriptor(
  name='PbFamilyProxy',
  full_name='PbFamilyProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbFamilyProxy.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbFamilyProxy.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle_point', full_name='PbFamilyProxy.cycle_point', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='PbFamilyProxy.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family', full_name='PbFamilyProxy.family', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='PbFamilyProxy.state', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='PbFamilyProxy.depth', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_parent', full_name='PbFamilyProxy.first_parent', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parents', full_name='PbFamilyProxy.parents', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_tasks', full_name='PbFamilyProxy.child_tasks', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_families', full_name='PbFamilyProxy.child_families', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_held', full_name='PbFamilyProxy.is_held', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ancestors', full_name='PbFamilyProxy.ancestors', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbFamilyProxy._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbFamilyProxy._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cycle_point', full_name='PbFamilyProxy._cycle_point',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_name', full_name='PbFamilyProxy._name',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_family', full_name='PbFamilyProxy._family',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_state', full_name='PbFamilyProxy._state',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_depth', full_name='PbFamilyProxy._depth',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_first_parent', full_name='PbFamilyProxy._first_parent',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_is_held', full_name='PbFamilyProxy._is_held',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4350,
  serialized_end=4740,
)


_PBEDGE = _descriptor.Descriptor(
  name='PbEdge',
  full_name='PbEdge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='PbEdge.stamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='PbEdge.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='PbEdge.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='PbEdge.target', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suicide', full_name='PbEdge.suicide', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cond', full_name='PbEdge.cond', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_stamp', full_name='PbEdge._stamp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbEdge._id',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_source', full_name='PbEdge._source',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_target', full_name='PbEdge._target',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_suicide', full_name='PbEdge._suicide',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cond', full_name='PbEdge._cond',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4743,
  serialized_end=4931,
)


_PBEDGES = _descriptor.Descriptor(
  name='PbEdges',
  full_name='PbEdges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='PbEdges.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='PbEdges.edges', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_polling_tasks', full_name='PbEdges.workflow_polling_tasks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaves', full_name='PbEdges.leaves', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feet', full_name='PbEdges.feet', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_id', full_name='PbEdges._id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4933,
  serialized_end=5056,
)


_PBENTIREWORKFLOW = _descriptor.Descriptor(
  name='PbEntireWorkflow',
  full_name='PbEntireWorkflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='PbEntireWorkflow.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='PbEntireWorkflow.tasks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_proxies', full_name='PbEntireWorkflow.task_proxies', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobs', full_name='PbEntireWorkflow.jobs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='families', full_name='PbEntireWorkflow.families', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family_proxies', full_name='PbEntireWorkflow.family_proxies', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='PbEntireWorkflow.edges', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_workflow', full_name='PbEntireWorkflow._workflow',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5059,
  serialized_end=5301,
)


_EDELTAS = _descriptor.Descriptor(
  name='EDeltas',
  full_name='EDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='EDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='EDeltas.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='EDeltas.added', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='EDeltas.updated', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pruned', full_name='EDeltas.pruned', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='EDeltas.reloaded', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='EDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='EDeltas._checksum',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='EDeltas._reloaded',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5304,
  serialized_end=5479,
)


_FDELTAS = _descriptor.Descriptor(
  name='FDeltas',
  full_name='FDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='FDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='FDeltas.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='FDeltas.added', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='FDeltas.updated', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pruned', full_name='FDeltas.pruned', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='FDeltas.reloaded', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='FDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='FDeltas._checksum',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='FDeltas._reloaded',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5482,
  serialized_end=5661,
)


_FPDELTAS = _descriptor.Descriptor(
  name='FPDeltas',
  full_name='FPDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='FPDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='FPDeltas.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='FPDeltas.added', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='FPDeltas.updated', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pruned', full_name='FPDeltas.pruned', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='FPDeltas.reloaded', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='FPDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='FPDeltas._checksum',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='FPDeltas._reloaded',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5664,
  serialized_end=5854,
)


_JDELTAS = _descriptor.Descriptor(
  name='JDeltas',
  full_name='JDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='JDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='JDeltas.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='JDeltas.added', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='JDeltas.updated', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pruned', full_name='JDeltas.pruned', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='JDeltas.reloaded', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='JDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='JDeltas._checksum',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='JDeltas._reloaded',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5857,
  serialized_end=6030,
)


_TDELTAS = _descriptor.Descriptor(
  name='TDeltas',
  full_name='TDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='TDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='TDeltas.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='TDeltas.added', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='TDeltas.updated', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pruned', full_name='TDeltas.pruned', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='TDeltas.reloaded', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='TDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='TDeltas._checksum',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='TDeltas._reloaded',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6033,
  serialized_end=6208,
)


_TPDELTAS = _descriptor.Descriptor(
  name='TPDeltas',
  full_name='TPDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='TPDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='TPDeltas.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='TPDeltas.added', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='TPDeltas.updated', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pruned', full_name='TPDeltas.pruned', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='TPDeltas.reloaded', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='TPDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_checksum', full_name='TPDeltas._checksum',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='TPDeltas._reloaded',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6211,
  serialized_end=6397,
)


_WDELTAS = _descriptor.Descriptor(
  name='WDeltas',
  full_name='WDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='WDeltas.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added', full_name='WDeltas.added', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='WDeltas.updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloaded', full_name='WDeltas.reloaded', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_time', full_name='WDeltas._time',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_added', full_name='WDeltas._added',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_updated', full_name='WDeltas._updated',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reloaded', full_name='WDeltas._reloaded',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6400,
  serialized_end=6563,
)


_ALLDELTAS = _descriptor.Descriptor(
  name='AllDeltas',
  full_name='AllDeltas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='families', full_name='AllDeltas.families', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family_proxies', full_name='AllDeltas.family_proxies', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobs', full_name='AllDeltas.jobs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='AllDeltas.tasks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_proxies', full_name='AllDeltas.task_proxies', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='AllDeltas.edges', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='AllDeltas.workflow', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6566,
  serialized_end=6775,
)

_PBMETA.oneofs_by_name['_title'].fields.append(
  _PBMETA.fields_by_name['title'])
_PBMETA.fields_by_name['title'].containing_oneof = _PBMETA.oneofs_by_name['_title']
_PBMETA.oneofs_by_name['_description'].fields.append(
  _PBMETA.fields_by_name['description'])
_PBMETA.fields_by_name['description'].containing_oneof = _PBMETA.oneofs_by_name['_description']
_PBMETA.oneofs_by_name['_URL'].fields.append(
  _PBMETA.fields_by_name['URL'])
_PBMETA.fields_by_name['URL'].containing_oneof = _PBMETA.oneofs_by_name['_URL']
_PBTIMEZONE.oneofs_by_name['_hours'].fields.append(
  _PBTIMEZONE.fields_by_name['hours'])
_PBTIMEZONE.fields_by_name['hours'].containing_oneof = _PBTIMEZONE.oneofs_by_name['_hours']
_PBTIMEZONE.oneofs_by_name['_minutes'].fields.append(
  _PBTIMEZONE.fields_by_name['minutes'])
_PBTIMEZONE.fields_by_name['minutes'].containing_oneof = _PBTIMEZONE.oneofs_by_name['_minutes']
_PBTIMEZONE.oneofs_by_name['_string_basic'].fields.append(
  _PBTIMEZONE.fields_by_name['string_basic'])
_PBTIMEZONE.fields_by_name['string_basic'].containing_oneof = _PBTIMEZONE.oneofs_by_name['_string_basic']
_PBTIMEZONE.oneofs_by_name['_string_extended'].fields.append(
  _PBTIMEZONE.fields_by_name['string_extended'])
_PBTIMEZONE.fields_by_name['string_extended'].containing_oneof = _PBTIMEZONE.oneofs_by_name['_string_extended']
_PBWORKFLOW_STATETOTALSENTRY.containing_type = _PBWORKFLOW
_PBWORKFLOW.fields_by_name['edges'].message_type = _PBEDGES
_PBWORKFLOW.fields_by_name['meta'].message_type = _PBMETA
_PBWORKFLOW.fields_by_name['state_totals'].message_type = _PBWORKFLOW_STATETOTALSENTRY
_PBWORKFLOW.fields_by_name['time_zone_info'].message_type = _PBTIMEZONE
_PBWORKFLOW.oneofs_by_name['_stamp'].fields.append(
  _PBWORKFLOW.fields_by_name['stamp'])
_PBWORKFLOW.fields_by_name['stamp'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_stamp']
_PBWORKFLOW.oneofs_by_name['_id'].fields.append(
  _PBWORKFLOW.fields_by_name['id'])
_PBWORKFLOW.fields_by_name['id'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_id']
_PBWORKFLOW.oneofs_by_name['_name'].fields.append(
  _PBWORKFLOW.fields_by_name['name'])
_PBWORKFLOW.fields_by_name['name'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_name']
_PBWORKFLOW.oneofs_by_name['_status'].fields.append(
  _PBWORKFLOW.fields_by_name['status'])
_PBWORKFLOW.fields_by_name['status'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_status']
_PBWORKFLOW.oneofs_by_name['_host'].fields.append(
  _PBWORKFLOW.fields_by_name['host'])
_PBWORKFLOW.fields_by_name['host'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_host']
_PBWORKFLOW.oneofs_by_name['_port'].fields.append(
  _PBWORKFLOW.fields_by_name['port'])
_PBWORKFLOW.fields_by_name['port'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_port']
_PBWORKFLOW.oneofs_by_name['_owner'].fields.append(
  _PBWORKFLOW.fields_by_name['owner'])
_PBWORKFLOW.fields_by_name['owner'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_owner']
_PBWORKFLOW.oneofs_by_name['_edges'].fields.append(
  _PBWORKFLOW.fields_by_name['edges'])
_PBWORKFLOW.fields_by_name['edges'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_edges']
_PBWORKFLOW.oneofs_by_name['_api_version'].fields.append(
  _PBWORKFLOW.fields_by_name['api_version'])
_PBWORKFLOW.fields_by_name['api_version'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_api_version']
_PBWORKFLOW.oneofs_by_name['_cylc_version'].fields.append(
  _PBWORKFLOW.fields_by_name['cylc_version'])
_PBWORKFLOW.fields_by_name['cylc_version'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_cylc_version']
_PBWORKFLOW.oneofs_by_name['_last_updated'].fields.append(
  _PBWORKFLOW.fields_by_name['last_updated'])
_PBWORKFLOW.fields_by_name['last_updated'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_last_updated']
_PBWORKFLOW.oneofs_by_name['_meta'].fields.append(
  _PBWORKFLOW.fields_by_name['meta'])
_PBWORKFLOW.fields_by_name['meta'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_meta']
_PBWORKFLOW.oneofs_by_name['_newest_runahead_cycle_point'].fields.append(
  _PBWORKFLOW.fields_by_name['newest_runahead_cycle_point'])
_PBWORKFLOW.fields_by_name['newest_runahead_cycle_point'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_newest_runahead_cycle_point']
_PBWORKFLOW.oneofs_by_name['_newest_cycle_point'].fields.append(
  _PBWORKFLOW.fields_by_name['newest_cycle_point'])
_PBWORKFLOW.fields_by_name['newest_cycle_point'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_newest_cycle_point']
_PBWORKFLOW.oneofs_by_name['_oldest_cycle_point'].fields.append(
  _PBWORKFLOW.fields_by_name['oldest_cycle_point'])
_PBWORKFLOW.fields_by_name['oldest_cycle_point'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_oldest_cycle_point']
_PBWORKFLOW.oneofs_by_name['_reloaded'].fields.append(
  _PBWORKFLOW.fields_by_name['reloaded'])
_PBWORKFLOW.fields_by_name['reloaded'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_reloaded']
_PBWORKFLOW.oneofs_by_name['_run_mode'].fields.append(
  _PBWORKFLOW.fields_by_name['run_mode'])
_PBWORKFLOW.fields_by_name['run_mode'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_run_mode']
_PBWORKFLOW.oneofs_by_name['_cycling_mode'].fields.append(
  _PBWORKFLOW.fields_by_name['cycling_mode'])
_PBWORKFLOW.fields_by_name['cycling_mode'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_cycling_mode']
_PBWORKFLOW.oneofs_by_name['_workflow_log_dir'].fields.append(
  _PBWORKFLOW.fields_by_name['workflow_log_dir'])
_PBWORKFLOW.fields_by_name['workflow_log_dir'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_workflow_log_dir']
_PBWORKFLOW.oneofs_by_name['_time_zone_info'].fields.append(
  _PBWORKFLOW.fields_by_name['time_zone_info'])
_PBWORKFLOW.fields_by_name['time_zone_info'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_time_zone_info']
_PBWORKFLOW.oneofs_by_name['_tree_depth'].fields.append(
  _PBWORKFLOW.fields_by_name['tree_depth'])
_PBWORKFLOW.fields_by_name['tree_depth'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_tree_depth']
_PBWORKFLOW.oneofs_by_name['_status_msg'].fields.append(
  _PBWORKFLOW.fields_by_name['status_msg'])
_PBWORKFLOW.fields_by_name['status_msg'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_status_msg']
_PBWORKFLOW.oneofs_by_name['_is_held_total'].fields.append(
  _PBWORKFLOW.fields_by_name['is_held_total'])
_PBWORKFLOW.fields_by_name['is_held_total'].containing_oneof = _PBWORKFLOW.oneofs_by_name['_is_held_total']
_PBJOB.oneofs_by_name['_stamp'].fields.append(
  _PBJOB.fields_by_name['stamp'])
_PBJOB.fields_by_name['stamp'].containing_oneof = _PBJOB.oneofs_by_name['_stamp']
_PBJOB.oneofs_by_name['_id'].fields.append(
  _PBJOB.fields_by_name['id'])
_PBJOB.fields_by_name['id'].containing_oneof = _PBJOB.oneofs_by_name['_id']
_PBJOB.oneofs_by_name['_submit_num'].fields.append(
  _PBJOB.fields_by_name['submit_num'])
_PBJOB.fields_by_name['submit_num'].containing_oneof = _PBJOB.oneofs_by_name['_submit_num']
_PBJOB.oneofs_by_name['_state'].fields.append(
  _PBJOB.fields_by_name['state'])
_PBJOB.fields_by_name['state'].containing_oneof = _PBJOB.oneofs_by_name['_state']
_PBJOB.oneofs_by_name['_task_proxy'].fields.append(
  _PBJOB.fields_by_name['task_proxy'])
_PBJOB.fields_by_name['task_proxy'].containing_oneof = _PBJOB.oneofs_by_name['_task_proxy']
_PBJOB.oneofs_by_name['_submitted_time'].fields.append(
  _PBJOB.fields_by_name['submitted_time'])
_PBJOB.fields_by_name['submitted_time'].containing_oneof = _PBJOB.oneofs_by_name['_submitted_time']
_PBJOB.oneofs_by_name['_started_time'].fields.append(
  _PBJOB.fields_by_name['started_time'])
_PBJOB.fields_by_name['started_time'].containing_oneof = _PBJOB.oneofs_by_name['_started_time']
_PBJOB.oneofs_by_name['_finished_time'].fields.append(
  _PBJOB.fields_by_name['finished_time'])
_PBJOB.fields_by_name['finished_time'].containing_oneof = _PBJOB.oneofs_by_name['_finished_time']
_PBJOB.oneofs_by_name['_batch_sys_job_id'].fields.append(
  _PBJOB.fields_by_name['batch_sys_job_id'])
_PBJOB.fields_by_name['batch_sys_job_id'].containing_oneof = _PBJOB.oneofs_by_name['_batch_sys_job_id']
_PBJOB.oneofs_by_name['_batch_sys_name'].fields.append(
  _PBJOB.fields_by_name['batch_sys_name'])
_PBJOB.fields_by_name['batch_sys_name'].containing_oneof = _PBJOB.oneofs_by_name['_batch_sys_name']
_PBJOB.oneofs_by_name['_env_script'].fields.append(
  _PBJOB.fields_by_name['env_script'])
_PBJOB.fields_by_name['env_script'].containing_oneof = _PBJOB.oneofs_by_name['_env_script']
_PBJOB.oneofs_by_name['_err_script'].fields.append(
  _PBJOB.fields_by_name['err_script'])
_PBJOB.fields_by_name['err_script'].containing_oneof = _PBJOB.oneofs_by_name['_err_script']
_PBJOB.oneofs_by_name['_exit_script'].fields.append(
  _PBJOB.fields_by_name['exit_script'])
_PBJOB.fields_by_name['exit_script'].containing_oneof = _PBJOB.oneofs_by_name['_exit_script']
_PBJOB.oneofs_by_name['_execution_time_limit'].fields.append(
  _PBJOB.fields_by_name['execution_time_limit'])
_PBJOB.fields_by_name['execution_time_limit'].containing_oneof = _PBJOB.oneofs_by_name['_execution_time_limit']
_PBJOB.oneofs_by_name['_host'].fields.append(
  _PBJOB.fields_by_name['host'])
_PBJOB.fields_by_name['host'].containing_oneof = _PBJOB.oneofs_by_name['_host']
_PBJOB.oneofs_by_name['_init_script'].fields.append(
  _PBJOB.fields_by_name['init_script'])
_PBJOB.fields_by_name['init_script'].containing_oneof = _PBJOB.oneofs_by_name['_init_script']
_PBJOB.oneofs_by_name['_job_log_dir'].fields.append(
  _PBJOB.fields_by_name['job_log_dir'])
_PBJOB.fields_by_name['job_log_dir'].containing_oneof = _PBJOB.oneofs_by_name['_job_log_dir']
_PBJOB.oneofs_by_name['_owner'].fields.append(
  _PBJOB.fields_by_name['owner'])
_PBJOB.fields_by_name['owner'].containing_oneof = _PBJOB.oneofs_by_name['_owner']
_PBJOB.oneofs_by_name['_post_script'].fields.append(
  _PBJOB.fields_by_name['post_script'])
_PBJOB.fields_by_name['post_script'].containing_oneof = _PBJOB.oneofs_by_name['_post_script']
_PBJOB.oneofs_by_name['_pre_script'].fields.append(
  _PBJOB.fields_by_name['pre_script'])
_PBJOB.fields_by_name['pre_script'].containing_oneof = _PBJOB.oneofs_by_name['_pre_script']
_PBJOB.oneofs_by_name['_script'].fields.append(
  _PBJOB.fields_by_name['script'])
_PBJOB.fields_by_name['script'].containing_oneof = _PBJOB.oneofs_by_name['_script']
_PBJOB.oneofs_by_name['_shell'].fields.append(
  _PBJOB.fields_by_name['shell'])
_PBJOB.fields_by_name['shell'].containing_oneof = _PBJOB.oneofs_by_name['_shell']
_PBJOB.oneofs_by_name['_work_sub_dir'].fields.append(
  _PBJOB.fields_by_name['work_sub_dir'])
_PBJOB.fields_by_name['work_sub_dir'].containing_oneof = _PBJOB.oneofs_by_name['_work_sub_dir']
_PBJOB.oneofs_by_name['_name'].fields.append(
  _PBJOB.fields_by_name['name'])
_PBJOB.fields_by_name['name'].containing_oneof = _PBJOB.oneofs_by_name['_name']
_PBJOB.oneofs_by_name['_cycle_point'].fields.append(
  _PBJOB.fields_by_name['cycle_point'])
_PBJOB.fields_by_name['cycle_point'].containing_oneof = _PBJOB.oneofs_by_name['_cycle_point']
_PBTASK.fields_by_name['meta'].message_type = _PBMETA
_PBTASK.oneofs_by_name['_stamp'].fields.append(
  _PBTASK.fields_by_name['stamp'])
_PBTASK.fields_by_name['stamp'].containing_oneof = _PBTASK.oneofs_by_name['_stamp']
_PBTASK.oneofs_by_name['_id'].fields.append(
  _PBTASK.fields_by_name['id'])
_PBTASK.fields_by_name['id'].containing_oneof = _PBTASK.oneofs_by_name['_id']
_PBTASK.oneofs_by_name['_name'].fields.append(
  _PBTASK.fields_by_name['name'])
_PBTASK.fields_by_name['name'].containing_oneof = _PBTASK.oneofs_by_name['_name']
_PBTASK.oneofs_by_name['_meta'].fields.append(
  _PBTASK.fields_by_name['meta'])
_PBTASK.fields_by_name['meta'].containing_oneof = _PBTASK.oneofs_by_name['_meta']
_PBTASK.oneofs_by_name['_mean_elapsed_time'].fields.append(
  _PBTASK.fields_by_name['mean_elapsed_time'])
_PBTASK.fields_by_name['mean_elapsed_time'].containing_oneof = _PBTASK.oneofs_by_name['_mean_elapsed_time']
_PBTASK.oneofs_by_name['_depth'].fields.append(
  _PBTASK.fields_by_name['depth'])
_PBTASK.fields_by_name['depth'].containing_oneof = _PBTASK.oneofs_by_name['_depth']
_PBPOLLTASK.oneofs_by_name['_local_proxy'].fields.append(
  _PBPOLLTASK.fields_by_name['local_proxy'])
_PBPOLLTASK.fields_by_name['local_proxy'].containing_oneof = _PBPOLLTASK.oneofs_by_name['_local_proxy']
_PBPOLLTASK.oneofs_by_name['_workflow'].fields.append(
  _PBPOLLTASK.fields_by_name['workflow'])
_PBPOLLTASK.fields_by_name['workflow'].containing_oneof = _PBPOLLTASK.oneofs_by_name['_workflow']
_PBPOLLTASK.oneofs_by_name['_remote_proxy'].fields.append(
  _PBPOLLTASK.fields_by_name['remote_proxy'])
_PBPOLLTASK.fields_by_name['remote_proxy'].containing_oneof = _PBPOLLTASK.oneofs_by_name['_remote_proxy']
_PBPOLLTASK.oneofs_by_name['_req_state'].fields.append(
  _PBPOLLTASK.fields_by_name['req_state'])
_PBPOLLTASK.fields_by_name['req_state'].containing_oneof = _PBPOLLTASK.oneofs_by_name['_req_state']
_PBPOLLTASK.oneofs_by_name['_graph_string'].fields.append(
  _PBPOLLTASK.fields_by_name['graph_string'])
_PBPOLLTASK.fields_by_name['graph_string'].containing_oneof = _PBPOLLTASK.oneofs_by_name['_graph_string']
_PBCONDITION.oneofs_by_name['_task_proxy'].fields.append(
  _PBCONDITION.fields_by_name['task_proxy'])
_PBCONDITION.fields_by_name['task_proxy'].containing_oneof = _PBCONDITION.oneofs_by_name['_task_proxy']
_PBCONDITION.oneofs_by_name['_expr_alias'].fields.append(
  _PBCONDITION.fields_by_name['expr_alias'])
_PBCONDITION.fields_by_name['expr_alias'].containing_oneof = _PBCONDITION.oneofs_by_name['_expr_alias']
_PBCONDITION.oneofs_by_name['_req_state'].fields.append(
  _PBCONDITION.fields_by_name['req_state'])
_PBCONDITION.fields_by_name['req_state'].containing_oneof = _PBCONDITION.oneofs_by_name['_req_state']
_PBCONDITION.oneofs_by_name['_satisfied'].fields.append(
  _PBCONDITION.fields_by_name['satisfied'])
_PBCONDITION.fields_by_name['satisfied'].containing_oneof = _PBCONDITION.oneofs_by_name['_satisfied']
_PBCONDITION.oneofs_by_name['_message'].fields.append(
  _PBCONDITION.fields_by_name['message'])
_PBCONDITION.fields_by_name['message'].containing_oneof = _PBCONDITION.oneofs_by_name['_message']
_PBPREREQUISITE.fields_by_name['conditions'].message_type = _PBCONDITION
_PBPREREQUISITE.oneofs_by_name['_expression'].fields.append(
  _PBPREREQUISITE.fields_by_name['expression'])
_PBPREREQUISITE.fields_by_name['expression'].containing_oneof = _PBPREREQUISITE.oneofs_by_name['_expression']
_PBPREREQUISITE.oneofs_by_name['_satisfied'].fields.append(
  _PBPREREQUISITE.fields_by_name['satisfied'])
_PBPREREQUISITE.fields_by_name['satisfied'].containing_oneof = _PBPREREQUISITE.oneofs_by_name['_satisfied']
_PBTASKPROXY.fields_by_name['prerequisites'].message_type = _PBPREREQUISITE
_PBTASKPROXY.oneofs_by_name['_stamp'].fields.append(
  _PBTASKPROXY.fields_by_name['stamp'])
_PBTASKPROXY.fields_by_name['stamp'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_stamp']
_PBTASKPROXY.oneofs_by_name['_id'].fields.append(
  _PBTASKPROXY.fields_by_name['id'])
_PBTASKPROXY.fields_by_name['id'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_id']
_PBTASKPROXY.oneofs_by_name['_task'].fields.append(
  _PBTASKPROXY.fields_by_name['task'])
_PBTASKPROXY.fields_by_name['task'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_task']
_PBTASKPROXY.oneofs_by_name['_state'].fields.append(
  _PBTASKPROXY.fields_by_name['state'])
_PBTASKPROXY.fields_by_name['state'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_state']
_PBTASKPROXY.oneofs_by_name['_cycle_point'].fields.append(
  _PBTASKPROXY.fields_by_name['cycle_point'])
_PBTASKPROXY.fields_by_name['cycle_point'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_cycle_point']
_PBTASKPROXY.oneofs_by_name['_spawned'].fields.append(
  _PBTASKPROXY.fields_by_name['spawned'])
_PBTASKPROXY.fields_by_name['spawned'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_spawned']
_PBTASKPROXY.oneofs_by_name['_depth'].fields.append(
  _PBTASKPROXY.fields_by_name['depth'])
_PBTASKPROXY.fields_by_name['depth'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_depth']
_PBTASKPROXY.oneofs_by_name['_job_submits'].fields.append(
  _PBTASKPROXY.fields_by_name['job_submits'])
_PBTASKPROXY.fields_by_name['job_submits'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_job_submits']
_PBTASKPROXY.oneofs_by_name['_latest_message'].fields.append(
  _PBTASKPROXY.fields_by_name['latest_message'])
_PBTASKPROXY.fields_by_name['latest_message'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_latest_message']
_PBTASKPROXY.oneofs_by_name['_first_parent'].fields.append(
  _PBTASKPROXY.fields_by_name['first_parent'])
_PBTASKPROXY.fields_by_name['first_parent'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_first_parent']
_PBTASKPROXY.oneofs_by_name['_name'].fields.append(
  _PBTASKPROXY.fields_by_name['name'])
_PBTASKPROXY.fields_by_name['name'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_name']
_PBTASKPROXY.oneofs_by_name['_is_held'].fields.append(
  _PBTASKPROXY.fields_by_name['is_held'])
_PBTASKPROXY.fields_by_name['is_held'].containing_oneof = _PBTASKPROXY.oneofs_by_name['_is_held']
_PBFAMILY.fields_by_name['meta'].message_type = _PBMETA
_PBFAMILY.oneofs_by_name['_stamp'].fields.append(
  _PBFAMILY.fields_by_name['stamp'])
_PBFAMILY.fields_by_name['stamp'].containing_oneof = _PBFAMILY.oneofs_by_name['_stamp']
_PBFAMILY.oneofs_by_name['_id'].fields.append(
  _PBFAMILY.fields_by_name['id'])
_PBFAMILY.fields_by_name['id'].containing_oneof = _PBFAMILY.oneofs_by_name['_id']
_PBFAMILY.oneofs_by_name['_name'].fields.append(
  _PBFAMILY.fields_by_name['name'])
_PBFAMILY.fields_by_name['name'].containing_oneof = _PBFAMILY.oneofs_by_name['_name']
_PBFAMILY.oneofs_by_name['_meta'].fields.append(
  _PBFAMILY.fields_by_name['meta'])
_PBFAMILY.fields_by_name['meta'].containing_oneof = _PBFAMILY.oneofs_by_name['_meta']
_PBFAMILY.oneofs_by_name['_depth'].fields.append(
  _PBFAMILY.fields_by_name['depth'])
_PBFAMILY.fields_by_name['depth'].containing_oneof = _PBFAMILY.oneofs_by_name['_depth']
_PBFAMILYPROXY.oneofs_by_name['_stamp'].fields.append(
  _PBFAMILYPROXY.fields_by_name['stamp'])
_PBFAMILYPROXY.fields_by_name['stamp'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_stamp']
_PBFAMILYPROXY.oneofs_by_name['_id'].fields.append(
  _PBFAMILYPROXY.fields_by_name['id'])
_PBFAMILYPROXY.fields_by_name['id'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_id']
_PBFAMILYPROXY.oneofs_by_name['_cycle_point'].fields.append(
  _PBFAMILYPROXY.fields_by_name['cycle_point'])
_PBFAMILYPROXY.fields_by_name['cycle_point'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_cycle_point']
_PBFAMILYPROXY.oneofs_by_name['_name'].fields.append(
  _PBFAMILYPROXY.fields_by_name['name'])
_PBFAMILYPROXY.fields_by_name['name'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_name']
_PBFAMILYPROXY.oneofs_by_name['_family'].fields.append(
  _PBFAMILYPROXY.fields_by_name['family'])
_PBFAMILYPROXY.fields_by_name['family'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_family']
_PBFAMILYPROXY.oneofs_by_name['_state'].fields.append(
  _PBFAMILYPROXY.fields_by_name['state'])
_PBFAMILYPROXY.fields_by_name['state'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_state']
_PBFAMILYPROXY.oneofs_by_name['_depth'].fields.append(
  _PBFAMILYPROXY.fields_by_name['depth'])
_PBFAMILYPROXY.fields_by_name['depth'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_depth']
_PBFAMILYPROXY.oneofs_by_name['_first_parent'].fields.append(
  _PBFAMILYPROXY.fields_by_name['first_parent'])
_PBFAMILYPROXY.fields_by_name['first_parent'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_first_parent']
_PBFAMILYPROXY.oneofs_by_name['_is_held'].fields.append(
  _PBFAMILYPROXY.fields_by_name['is_held'])
_PBFAMILYPROXY.fields_by_name['is_held'].containing_oneof = _PBFAMILYPROXY.oneofs_by_name['_is_held']
_PBEDGE.oneofs_by_name['_stamp'].fields.append(
  _PBEDGE.fields_by_name['stamp'])
_PBEDGE.fields_by_name['stamp'].containing_oneof = _PBEDGE.oneofs_by_name['_stamp']
_PBEDGE.oneofs_by_name['_id'].fields.append(
  _PBEDGE.fields_by_name['id'])
_PBEDGE.fields_by_name['id'].containing_oneof = _PBEDGE.oneofs_by_name['_id']
_PBEDGE.oneofs_by_name['_source'].fields.append(
  _PBEDGE.fields_by_name['source'])
_PBEDGE.fields_by_name['source'].containing_oneof = _PBEDGE.oneofs_by_name['_source']
_PBEDGE.oneofs_by_name['_target'].fields.append(
  _PBEDGE.fields_by_name['target'])
_PBEDGE.fields_by_name['target'].containing_oneof = _PBEDGE.oneofs_by_name['_target']
_PBEDGE.oneofs_by_name['_suicide'].fields.append(
  _PBEDGE.fields_by_name['suicide'])
_PBEDGE.fields_by_name['suicide'].containing_oneof = _PBEDGE.oneofs_by_name['_suicide']
_PBEDGE.oneofs_by_name['_cond'].fields.append(
  _PBEDGE.fields_by_name['cond'])
_PBEDGE.fields_by_name['cond'].containing_oneof = _PBEDGE.oneofs_by_name['_cond']
_PBEDGES.fields_by_name['workflow_polling_tasks'].message_type = _PBPOLLTASK
_PBEDGES.oneofs_by_name['_id'].fields.append(
  _PBEDGES.fields_by_name['id'])
_PBEDGES.fields_by_name['id'].containing_oneof = _PBEDGES.oneofs_by_name['_id']
_PBENTIREWORKFLOW.fields_by_name['workflow'].message_type = _PBWORKFLOW
_PBENTIREWORKFLOW.fields_by_name['tasks'].message_type = _PBTASK
_PBENTIREWORKFLOW.fields_by_name['task_proxies'].message_type = _PBTASKPROXY
_PBENTIREWORKFLOW.fields_by_name['jobs'].message_type = _PBJOB
_PBENTIREWORKFLOW.fields_by_name['families'].message_type = _PBFAMILY
_PBENTIREWORKFLOW.fields_by_name['family_proxies'].message_type = _PBFAMILYPROXY
_PBENTIREWORKFLOW.fields_by_name['edges'].message_type = _PBEDGE
_PBENTIREWORKFLOW.oneofs_by_name['_workflow'].fields.append(
  _PBENTIREWORKFLOW.fields_by_name['workflow'])
_PBENTIREWORKFLOW.fields_by_name['workflow'].containing_oneof = _PBENTIREWORKFLOW.oneofs_by_name['_workflow']
_EDELTAS.fields_by_name['added'].message_type = _PBEDGE
_EDELTAS.fields_by_name['updated'].message_type = _PBEDGE
_EDELTAS.oneofs_by_name['_time'].fields.append(
  _EDELTAS.fields_by_name['time'])
_EDELTAS.fields_by_name['time'].containing_oneof = _EDELTAS.oneofs_by_name['_time']
_EDELTAS.oneofs_by_name['_checksum'].fields.append(
  _EDELTAS.fields_by_name['checksum'])
_EDELTAS.fields_by_name['checksum'].containing_oneof = _EDELTAS.oneofs_by_name['_checksum']
_EDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _EDELTAS.fields_by_name['reloaded'])
_EDELTAS.fields_by_name['reloaded'].containing_oneof = _EDELTAS.oneofs_by_name['_reloaded']
_FDELTAS.fields_by_name['added'].message_type = _PBFAMILY
_FDELTAS.fields_by_name['updated'].message_type = _PBFAMILY
_FDELTAS.oneofs_by_name['_time'].fields.append(
  _FDELTAS.fields_by_name['time'])
_FDELTAS.fields_by_name['time'].containing_oneof = _FDELTAS.oneofs_by_name['_time']
_FDELTAS.oneofs_by_name['_checksum'].fields.append(
  _FDELTAS.fields_by_name['checksum'])
_FDELTAS.fields_by_name['checksum'].containing_oneof = _FDELTAS.oneofs_by_name['_checksum']
_FDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _FDELTAS.fields_by_name['reloaded'])
_FDELTAS.fields_by_name['reloaded'].containing_oneof = _FDELTAS.oneofs_by_name['_reloaded']
_FPDELTAS.fields_by_name['added'].message_type = _PBFAMILYPROXY
_FPDELTAS.fields_by_name['updated'].message_type = _PBFAMILYPROXY
_FPDELTAS.oneofs_by_name['_time'].fields.append(
  _FPDELTAS.fields_by_name['time'])
_FPDELTAS.fields_by_name['time'].containing_oneof = _FPDELTAS.oneofs_by_name['_time']
_FPDELTAS.oneofs_by_name['_checksum'].fields.append(
  _FPDELTAS.fields_by_name['checksum'])
_FPDELTAS.fields_by_name['checksum'].containing_oneof = _FPDELTAS.oneofs_by_name['_checksum']
_FPDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _FPDELTAS.fields_by_name['reloaded'])
_FPDELTAS.fields_by_name['reloaded'].containing_oneof = _FPDELTAS.oneofs_by_name['_reloaded']
_JDELTAS.fields_by_name['added'].message_type = _PBJOB
_JDELTAS.fields_by_name['updated'].message_type = _PBJOB
_JDELTAS.oneofs_by_name['_time'].fields.append(
  _JDELTAS.fields_by_name['time'])
_JDELTAS.fields_by_name['time'].containing_oneof = _JDELTAS.oneofs_by_name['_time']
_JDELTAS.oneofs_by_name['_checksum'].fields.append(
  _JDELTAS.fields_by_name['checksum'])
_JDELTAS.fields_by_name['checksum'].containing_oneof = _JDELTAS.oneofs_by_name['_checksum']
_JDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _JDELTAS.fields_by_name['reloaded'])
_JDELTAS.fields_by_name['reloaded'].containing_oneof = _JDELTAS.oneofs_by_name['_reloaded']
_TDELTAS.fields_by_name['added'].message_type = _PBTASK
_TDELTAS.fields_by_name['updated'].message_type = _PBTASK
_TDELTAS.oneofs_by_name['_time'].fields.append(
  _TDELTAS.fields_by_name['time'])
_TDELTAS.fields_by_name['time'].containing_oneof = _TDELTAS.oneofs_by_name['_time']
_TDELTAS.oneofs_by_name['_checksum'].fields.append(
  _TDELTAS.fields_by_name['checksum'])
_TDELTAS.fields_by_name['checksum'].containing_oneof = _TDELTAS.oneofs_by_name['_checksum']
_TDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _TDELTAS.fields_by_name['reloaded'])
_TDELTAS.fields_by_name['reloaded'].containing_oneof = _TDELTAS.oneofs_by_name['_reloaded']
_TPDELTAS.fields_by_name['added'].message_type = _PBTASKPROXY
_TPDELTAS.fields_by_name['updated'].message_type = _PBTASKPROXY
_TPDELTAS.oneofs_by_name['_time'].fields.append(
  _TPDELTAS.fields_by_name['time'])
_TPDELTAS.fields_by_name['time'].containing_oneof = _TPDELTAS.oneofs_by_name['_time']
_TPDELTAS.oneofs_by_name['_checksum'].fields.append(
  _TPDELTAS.fields_by_name['checksum'])
_TPDELTAS.fields_by_name['checksum'].containing_oneof = _TPDELTAS.oneofs_by_name['_checksum']
_TPDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _TPDELTAS.fields_by_name['reloaded'])
_TPDELTAS.fields_by_name['reloaded'].containing_oneof = _TPDELTAS.oneofs_by_name['_reloaded']
_WDELTAS.fields_by_name['added'].message_type = _PBWORKFLOW
_WDELTAS.fields_by_name['updated'].message_type = _PBWORKFLOW
_WDELTAS.oneofs_by_name['_time'].fields.append(
  _WDELTAS.fields_by_name['time'])
_WDELTAS.fields_by_name['time'].containing_oneof = _WDELTAS.oneofs_by_name['_time']
_WDELTAS.oneofs_by_name['_added'].fields.append(
  _WDELTAS.fields_by_name['added'])
_WDELTAS.fields_by_name['added'].containing_oneof = _WDELTAS.oneofs_by_name['_added']
_WDELTAS.oneofs_by_name['_updated'].fields.append(
  _WDELTAS.fields_by_name['updated'])
_WDELTAS.fields_by_name['updated'].containing_oneof = _WDELTAS.oneofs_by_name['_updated']
_WDELTAS.oneofs_by_name['_reloaded'].fields.append(
  _WDELTAS.fields_by_name['reloaded'])
_WDELTAS.fields_by_name['reloaded'].containing_oneof = _WDELTAS.oneofs_by_name['_reloaded']
_ALLDELTAS.fields_by_name['families'].message_type = _FDELTAS
_ALLDELTAS.fields_by_name['family_proxies'].message_type = _FPDELTAS
_ALLDELTAS.fields_by_name['jobs'].message_type = _JDELTAS
_ALLDELTAS.fields_by_name['tasks'].message_type = _TDELTAS
_ALLDELTAS.fields_by_name['task_proxies'].message_type = _TPDELTAS
_ALLDELTAS.fields_by_name['edges'].message_type = _EDELTAS
_ALLDELTAS.fields_by_name['workflow'].message_type = _WDELTAS
DESCRIPTOR.message_types_by_name['PbMeta'] = _PBMETA
DESCRIPTOR.message_types_by_name['PbTimeZone'] = _PBTIMEZONE
DESCRIPTOR.message_types_by_name['PbWorkflow'] = _PBWORKFLOW
DESCRIPTOR.message_types_by_name['PbJob'] = _PBJOB
DESCRIPTOR.message_types_by_name['PbTask'] = _PBTASK
DESCRIPTOR.message_types_by_name['PbPollTask'] = _PBPOLLTASK
DESCRIPTOR.message_types_by_name['PbCondition'] = _PBCONDITION
DESCRIPTOR.message_types_by_name['PbPrerequisite'] = _PBPREREQUISITE
DESCRIPTOR.message_types_by_name['PbTaskProxy'] = _PBTASKPROXY
DESCRIPTOR.message_types_by_name['PbFamily'] = _PBFAMILY
DESCRIPTOR.message_types_by_name['PbFamilyProxy'] = _PBFAMILYPROXY
DESCRIPTOR.message_types_by_name['PbEdge'] = _PBEDGE
DESCRIPTOR.message_types_by_name['PbEdges'] = _PBEDGES
DESCRIPTOR.message_types_by_name['PbEntireWorkflow'] = _PBENTIREWORKFLOW
DESCRIPTOR.message_types_by_name['EDeltas'] = _EDELTAS
DESCRIPTOR.message_types_by_name['FDeltas'] = _FDELTAS
DESCRIPTOR.message_types_by_name['FPDeltas'] = _FPDELTAS
DESCRIPTOR.message_types_by_name['JDeltas'] = _JDELTAS
DESCRIPTOR.message_types_by_name['TDeltas'] = _TDELTAS
DESCRIPTOR.message_types_by_name['TPDeltas'] = _TPDELTAS
DESCRIPTOR.message_types_by_name['WDeltas'] = _WDELTAS
DESCRIPTOR.message_types_by_name['AllDeltas'] = _ALLDELTAS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PbMeta = _reflection.GeneratedProtocolMessageType('PbMeta', (_message.Message,), {
  'DESCRIPTOR' : _PBMETA,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbMeta)
  })
_sym_db.RegisterMessage(PbMeta)

PbTimeZone = _reflection.GeneratedProtocolMessageType('PbTimeZone', (_message.Message,), {
  'DESCRIPTOR' : _PBTIMEZONE,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbTimeZone)
  })
_sym_db.RegisterMessage(PbTimeZone)

PbWorkflow = _reflection.GeneratedProtocolMessageType('PbWorkflow', (_message.Message,), {

  'StateTotalsEntry' : _reflection.GeneratedProtocolMessageType('StateTotalsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PBWORKFLOW_STATETOTALSENTRY,
    '__module__' : 'data_messages_pb2'
    # @@protoc_insertion_point(class_scope:PbWorkflow.StateTotalsEntry)
    })
  ,
  'DESCRIPTOR' : _PBWORKFLOW,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbWorkflow)
  })
_sym_db.RegisterMessage(PbWorkflow)
_sym_db.RegisterMessage(PbWorkflow.StateTotalsEntry)

PbJob = _reflection.GeneratedProtocolMessageType('PbJob', (_message.Message,), {
  'DESCRIPTOR' : _PBJOB,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbJob)
  })
_sym_db.RegisterMessage(PbJob)

PbTask = _reflection.GeneratedProtocolMessageType('PbTask', (_message.Message,), {
  'DESCRIPTOR' : _PBTASK,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbTask)
  })
_sym_db.RegisterMessage(PbTask)

PbPollTask = _reflection.GeneratedProtocolMessageType('PbPollTask', (_message.Message,), {
  'DESCRIPTOR' : _PBPOLLTASK,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbPollTask)
  })
_sym_db.RegisterMessage(PbPollTask)

PbCondition = _reflection.GeneratedProtocolMessageType('PbCondition', (_message.Message,), {
  'DESCRIPTOR' : _PBCONDITION,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbCondition)
  })
_sym_db.RegisterMessage(PbCondition)

PbPrerequisite = _reflection.GeneratedProtocolMessageType('PbPrerequisite', (_message.Message,), {
  'DESCRIPTOR' : _PBPREREQUISITE,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbPrerequisite)
  })
_sym_db.RegisterMessage(PbPrerequisite)

PbTaskProxy = _reflection.GeneratedProtocolMessageType('PbTaskProxy', (_message.Message,), {
  'DESCRIPTOR' : _PBTASKPROXY,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbTaskProxy)
  })
_sym_db.RegisterMessage(PbTaskProxy)

PbFamily = _reflection.GeneratedProtocolMessageType('PbFamily', (_message.Message,), {
  'DESCRIPTOR' : _PBFAMILY,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbFamily)
  })
_sym_db.RegisterMessage(PbFamily)

PbFamilyProxy = _reflection.GeneratedProtocolMessageType('PbFamilyProxy', (_message.Message,), {
  'DESCRIPTOR' : _PBFAMILYPROXY,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbFamilyProxy)
  })
_sym_db.RegisterMessage(PbFamilyProxy)

PbEdge = _reflection.GeneratedProtocolMessageType('PbEdge', (_message.Message,), {
  'DESCRIPTOR' : _PBEDGE,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbEdge)
  })
_sym_db.RegisterMessage(PbEdge)

PbEdges = _reflection.GeneratedProtocolMessageType('PbEdges', (_message.Message,), {
  'DESCRIPTOR' : _PBEDGES,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbEdges)
  })
_sym_db.RegisterMessage(PbEdges)

PbEntireWorkflow = _reflection.GeneratedProtocolMessageType('PbEntireWorkflow', (_message.Message,), {
  'DESCRIPTOR' : _PBENTIREWORKFLOW,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:PbEntireWorkflow)
  })
_sym_db.RegisterMessage(PbEntireWorkflow)

EDeltas = _reflection.GeneratedProtocolMessageType('EDeltas', (_message.Message,), {
  'DESCRIPTOR' : _EDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:EDeltas)
  })
_sym_db.RegisterMessage(EDeltas)

FDeltas = _reflection.GeneratedProtocolMessageType('FDeltas', (_message.Message,), {
  'DESCRIPTOR' : _FDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:FDeltas)
  })
_sym_db.RegisterMessage(FDeltas)

FPDeltas = _reflection.GeneratedProtocolMessageType('FPDeltas', (_message.Message,), {
  'DESCRIPTOR' : _FPDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:FPDeltas)
  })
_sym_db.RegisterMessage(FPDeltas)

JDeltas = _reflection.GeneratedProtocolMessageType('JDeltas', (_message.Message,), {
  'DESCRIPTOR' : _JDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:JDeltas)
  })
_sym_db.RegisterMessage(JDeltas)

TDeltas = _reflection.GeneratedProtocolMessageType('TDeltas', (_message.Message,), {
  'DESCRIPTOR' : _TDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:TDeltas)
  })
_sym_db.RegisterMessage(TDeltas)

TPDeltas = _reflection.GeneratedProtocolMessageType('TPDeltas', (_message.Message,), {
  'DESCRIPTOR' : _TPDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:TPDeltas)
  })
_sym_db.RegisterMessage(TPDeltas)

WDeltas = _reflection.GeneratedProtocolMessageType('WDeltas', (_message.Message,), {
  'DESCRIPTOR' : _WDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:WDeltas)
  })
_sym_db.RegisterMessage(WDeltas)

AllDeltas = _reflection.GeneratedProtocolMessageType('AllDeltas', (_message.Message,), {
  'DESCRIPTOR' : _ALLDELTAS,
  '__module__' : 'data_messages_pb2'
  # @@protoc_insertion_point(class_scope:AllDeltas)
  })
_sym_db.RegisterMessage(AllDeltas)


_PBWORKFLOW_STATETOTALSENTRY._options = None
# @@protoc_insertion_point(module_scope)
